package com.gic.haoban.manage.web.controller;

import java.util.List;

import com.alibaba.fastjson.JSON;
import com.ctrip.framework.apollo.spring.annotation.ApolloConfig;
import com.gic.haoban.common.utils.GlobalVar;
import com.gic.haoban.manage.api.dto.*;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.api.service.WxApplicationApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseApiService;
import com.gic.haoban.manage.web.anno.IgnoreLogin;
import com.gic.haoban.manage.web.auth.AuthRequestUtil;
import com.gic.haoban.manage.web.config.Config;
import com.gic.haoban.manage.web.vo.LoginVO;
import com.gic.wechat.api.service.qywx.QywxSuiteApiService;
import com.gic.wechat.api.service.qywx.QywxUserApiService;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.service.ApplicationApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;

@RestController
public class ApplicationController extends WebBaseController{
	private static final Logger log = LogManager.getLogger(ApplicationController.class);
	@Autowired
	private ApplicationApiService applicationApiService;
	@Autowired
	private QywxSuiteApiService qywxSuiteApiService;
	@Autowired
	private WxApplicationApiService wxApplicationApiService;
	@Autowired
	private WxEnterpriseApiService wxEnterpriseApiService;
	@Autowired
	private Config config;
	@Autowired
	private DepartmentApiService departmentApiService;
	
	@RequestMapping("application-list")
	public HaobanResponse applicationList() {
		
		List<ApplicationDTO> list = applicationApiService.listApplication();
		return resultResponse(HaoBanErrCode.ERR_1,list);
	}

	@RequestMapping("has-bind-contract")
	@IgnoreLogin
	public HaobanResponse hasBindContract(){
		LoginVO login = AuthRequestUtil.getSessionUser();
		String wxEnterpriseId = login.getWxEnterpriseId();
		WxApplicationDTO wxApplicationDTO = this.wxApplicationApiService.selectByWxEnterpriseIdAndApplicationType(wxEnterpriseId, 1);
		if(wxApplicationDTO != null){
			return resultResponse(HaoBanErrCode.ERR_1, true);
		}
		return resultResponse(HaoBanErrCode.ERR_1, false);
	}

	@RequestMapping("get-auth-url")
	@IgnoreLogin
	public HaobanResponse getAuthUrl(){
		String suiteId = config.getSuiteId();
		log.info("应用ID：{}", suiteId);
		String redictUrl = config.getHost() + "callback";
		String authorizationUrl = this.qywxSuiteApiService.getGrantAuthorizationUrl(suiteId, redictUrl);
		return resultResponse(HaoBanErrCode.ERR_1, authorizationUrl);
	}

	@RequestMapping("callback")
	@IgnoreLogin
	public HaobanResponse callback(String auth_code){
		String suiteId = config.getSuiteId();
		String result = this.qywxSuiteApiService.corpAuth(suiteId, auth_code);
		log.info("企业微信回调结果：{}. {}", auth_code, result);
		QywxCorpInfoDTO dto = JSON.parseObject(result, QywxCorpInfoDTO.class);
		WxApplicationDTO applicationDTO = new WxApplicationDTO();
		WxEnterpriseDTO enterpriseDTO = this.wxEnterpriseApiService.getEnterpriseBycorpId(dto.getCorpid());
		if(enterpriseDTO != null){
			applicationDTO.setName(dto.getAgentName());
			applicationDTO.setWxEnterpriseId(enterpriseDTO.getWxEnterpriseId());
			applicationDTO.setAgentId(dto.getAgentid());
			applicationDTO.setApplicationType(1);
			applicationDTO.setAgentName(dto.getAgentName());
			applicationDTO.setSiteId(dto.getSuiteId());
			wxApplicationApiService.addSuite(applicationDTO);
			this.departmentApiService.initwxDepartment(dto.getCorpid(), suiteId, enterpriseDTO.getWxEnterpriseId());
			enterpriseDTO.setContactFlag(1);
			wxEnterpriseApiService.update(enterpriseDTO);
			return resultResponse(HaoBanErrCode.ERR_1, result);
		}
		return resultResponse(HaoBanErrCode.ERR_0, dto);
	}

	@RequestMapping("cancal-suite")
	@IgnoreLogin
	public HaobanResponse cancelSuite(String corpId, String suiteId){
		this.wxApplicationApiService.cancelSuite(corpId, suiteId);
		return resultResponse(HaoBanErrCode.ERR_0, "s");
	}

	@Autowired
	private QywxUserApiService qywxUserApiService;
	@RequestMapping("list-external-user")
	@IgnoreLogin
	public Object list(String corpid, String suiteid, String userid){
		return this.qywxUserApiService.listExternalUserid(corpid, suiteid, userid);
	}

	@RequestMapping("corp-external-user")
	@IgnoreLogin
	public Object corpuserid(String corpid, String suiteid){
		return this.qywxUserApiService.listCorpExternalUser(corpid, suiteid);
	}
}
