package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.hutool.core.collection.CollectionUtil;

import com.gic.clerk.api.dto.ClerkDTO;
import com.gic.clerk.api.service.ClerkService;
import com.gic.commons.util.EntityUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.StaffDepartmentRelatedDTO;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.api.service.StaffDepartmentRelatedApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.vo.ClerkVo;

@RestController
public class ClerkController extends WebBaseController{
	@Autowired
	private ClerkService clerkService;
	@Autowired
	private DepartmentApiService departmentApiService;
	@Autowired
	private StaffDepartmentRelatedApiService staffDepartmentRelatedApiService;
	//未绑定的clerkCode列表
	@RequestMapping("/clerk-code-list")
	public HaobanResponse clerkCodeList(String departmentId) {
		List<StaffDepartmentRelatedDTO> list = staffDepartmentRelatedApiService.listByDepartmentId(departmentId);
		List<ClerkVo> result  = new ArrayList<ClerkVo>();
		if(StringUtils.isAnyBlank(departmentId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		DepartmentDTO departmentDTO = departmentApiService.selectById(departmentId);
		if(departmentDTO == null){
			return resultResponse(HaoBanErrCode.ERR_10009);
		}
		String storeId = departmentDTO.getRelatedId();
		if(StringUtils.isAnyBlank(departmentId)){
			return resultResponse(HaoBanErrCode.ERR_10009);
		}
		String bindFlag = "0";
		//绑定的clerk
		if("1".equals(bindFlag)){
			// 调陶接口获取详情数据
			if(CollectionUtil.isNotEmpty(list)){
				List<String> clerkCodes = list.stream().filter(s->s.getClerkCode()!=null).map(s->s.getClerkCode()).collect(Collectors.toList());
				if(CollectionUtil.isNotEmpty(clerkCodes)){
					List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, true);
					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
				}
			}
		}else{
			//未绑定的clerk
			// 调陶接口获取详情数据
			if(CollectionUtil.isNotEmpty(list)){
				List<String> clerkCodes = list.stream().filter(s->s.getClerkCode()!=null).map(s->s.getClerkCode()).collect(Collectors.toList());
				if(CollectionUtil.isNotEmpty(clerkCodes)){
					List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, false);
					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
				}
			}else{
				List<String> clerkCodes = new ArrayList();
				clerkCodes.add("xxxXXXX");
				List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, false);
				result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1,result);
		
	}
	//成员绑定
	@RequestMapping("/staff-bind")
	public HaobanResponse staffBind(String toClerkCode,String fromStaffDepartmentRelatedId) {
		if(StringUtils.isAnyBlank(toClerkCode,fromStaffDepartmentRelatedId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		//将指定人绑定clerkCode
		StaffDepartmentRelatedDTO dto = new StaffDepartmentRelatedDTO();
		dto.setStaffDepartmentRelatedId(fromStaffDepartmentRelatedId);
		dto.setClerkCode(toClerkCode);
		dto.setUpdateTime(new Date());
		staffDepartmentRelatedApiService.updateById(dto);
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	//成员换绑定
	@RequestMapping("/clerk-unbind")
	public HaobanResponse clerkUnbind(String departmentId,String fromClerkCode,String toClerkCode) {
		if(StringUtils.isAnyBlank(fromClerkCode,toClerkCode)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		//将别人clerkCode置空
		StaffDepartmentRelatedDTO one = staffDepartmentRelatedApiService.getOneByClerkCodeAndDepartmentId(toClerkCode,departmentId);
		if(one != null){
			//存在，则先置空
			one.setClerkCode(null);
			one.setUpdateTime(new Date());
			staffDepartmentRelatedApiService.deleteCode(one);
		}
		//将别人的clerkCode换到自己上面
		StaffDepartmentRelatedDTO two = staffDepartmentRelatedApiService.getOneByClerkCodeAndDepartmentId(fromClerkCode,departmentId);
		if(two != null){
			//存在，则先置空
			two.setClerkCode(toClerkCode);
			two.setUpdateTime(new Date());
			staffDepartmentRelatedApiService.updateById(two);
		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}

}
