package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.alibaba.fastjson.JSON;
import com.gic.api.base.commons.Page;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.base.api.common.PageResult;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.StaffDTO;
import com.gic.haoban.manage.api.dto.StaffDepartmentRelatedDTO;
import com.gic.haoban.manage.api.dto.WxApplicationDTO;
import com.gic.haoban.manage.api.dto.WxEnterpriseDTO;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.api.service.StaffDepartmentRelatedApiService;
import com.gic.haoban.manage.api.service.WxApplicationApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseApiService;
import com.gic.haoban.manage.web.auth.AuthRequestUtil;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.qo.StaffEditJsonQO;
import com.gic.haoban.manage.web.vo.LoginVO;
import com.gic.wechat.api.service.qywx.QywxUserApiService;


@RestController
public class StaffController extends WebBaseController{
	private static Logger logger  = LoggerFactory.getLogger(StaffController.class);
	
	@Autowired
	private StaffApiService staffApiService;
	@Autowired
	private DepartmentApiService departmentApiService;
	@Autowired
	private StaffDepartmentRelatedApiService staffDepartmentRelatedApiService;
	@Autowired
	private QywxUserApiService qywxUserApiService;
	@Autowired
	private WxEnterpriseApiService wxEnterpriseApiService;
	@Autowired
	private WxApplicationApiService wxApplicationApiService;
	
	@RequestMapping("staff-add")
	public HaobanResponse staffAdd(StaffDTO staffDTO,String departmentIds){
		LoginVO login = (LoginVO) AuthRequestUtil.getSessionUser();
		String wxEnterpriseId = login.getWxEnterpriseId();
		String staffName = staffDTO.getStaffName();
		String phoneNumber = staffDTO.getPhoneNumber();
		String nationcode = staffDTO.getNationCode();
		staffDTO.setWxEnterpriseId(wxEnterpriseId);
		if(StringUtils.isBlank(staffName)) {
			return resultResponse(HaoBanErrCode.ERR_10004);
		}
		StaffDTO staff = staffApiService.selectByNationcodeAndPhoneNumber(wxEnterpriseId,nationcode,phoneNumber);
		if(staff != null) {
			return resultResponse(HaoBanErrCode.ERR_10005);
		}
		HaobanResponse hr = staffApiService.add(staffDTO,departmentIds);
		if(hr.getErrorCode() == 0){
			return  resultResponse(HaoBanErrCode.ERR_DEFINE, hr.getDetailError(), null, hr.getDetailError());
		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	@RequestMapping("staff-sel")
	public HaobanResponse staffSel(String staffId,String staffDepartmentRelatedId){
		StaffDTO staff = staffApiService.selectById(staffId);
		List<StaffDepartmentRelatedDTO> list = staffApiService.listStaffDepartmentByStaffId(staffId);
		List<DepartmentDTO> departmentList = new ArrayList<DepartmentDTO>();
		for (StaffDepartmentRelatedDTO staffDepartmentRelatedDTO : list) {
			DepartmentDTO dto = departmentApiService.selectById(staffDepartmentRelatedDTO.getDepartmentId());
			departmentList.add(dto);
			
		}
		staff.setDepartmentList(departmentList);
		return resultResponse(HaoBanErrCode.ERR_1,staff);
	}
	
	@RequestMapping("staff-list")
	public HaobanResponse staffList(String departmentId,Integer activeFlag,String keyWord,BasePageInfo pageInfo){
		Page<StaffDTO> page = staffApiService.pageStaff(departmentId,activeFlag,keyWord,pageInfo);
		List<StaffDTO> list = page.getResult();
		if(list != null) {
			for (StaffDTO staffDTO : list) {
				logger.info("【成员列表】departmentId={},staffId={}",departmentId,staffDTO.getStaffId());
				StaffDepartmentRelatedDTO related = staffApiService.getDepartmentIdAndStaffId(departmentId,staffDTO.getStaffId());
				logger.info("【成员列表】related={}",JSON.toJSONString(related));
				if(related != null) {
					staffDTO.setStaffDepartmentRelatedId(related.getStaffDepartmentRelatedId());
					staffDTO.setClerkCode(related.getClerkCode());
				}
			}
		}
		
		logger.info("【员工列表】page={}",JSON.toJSONString(page));
		PageResult<StaffDTO> pageVo = new PageResult<>();
        pageVo.setList(list);
        pageVo.setPageNum(page.getCurrentPage());
        pageVo.setPages(page.getPages());
        pageVo.setPageSize(page.getPageSize());
        pageVo.setTotal(page.getTotalCount());
        logger.info("【员工列表】page={}",1);
        return resultResponse(HaoBanErrCode.ERR_1, page);
	}
	
	@RequestMapping("staff-del")
	public HaobanResponse staffDel(String staffDepartmentStaffRelatedId){
		staffApiService.del(staffDepartmentStaffRelatedId);
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	@RequestMapping("staff-batch-del")
	public HaobanResponse staffBatchDel(String staffDepartmentRelatedIds){
		if(StringUtils.isBlank(staffDepartmentRelatedIds)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		String[] staffArr = staffDepartmentRelatedIds.split(",");
		for (String string : staffArr) {
			staffApiService.del(string);
		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	@RequestMapping("staff-edit")
	public HaobanResponse staffEdit(StaffDTO staffDTO,String departmentIds){
		String staffId = staffDTO.getStaffId();
		StaffDTO staff = staffApiService.selectById(staffId);
		if(staff == null) {
			return resultResponse(HaoBanErrCode.ERR_10006);
		}
		
		staffApiService.staffEdit(staffDTO,departmentIds);
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	@RequestMapping("staff-invite")
	public HaobanResponse staffInvite(String staffIds){
		if(StringUtils.isBlank(staffIds)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		String[] staffArr = staffIds.split(",");
		List<String> userArr = new ArrayList<>();
		String wxEnterpriseId = "";
		for (String staffId : staffArr) {
			StaffDTO staff = staffApiService.selectById(staffId);
			if(staff != null){
				String userId = staff.getWxUserId();
				wxEnterpriseId = staff.getWxEnterpriseId();
				userArr.add(userId);
			}
		}
		WxEnterpriseDTO enterpriseDTO = wxEnterpriseApiService.getOne(wxEnterpriseId);
		WxApplicationDTO application = wxApplicationApiService.selectByWxEnterpriseIdAndApplicationType(wxEnterpriseId,1);
		if(enterpriseDTO != null) {
			if(application != null) {
				qywxUserApiService.inviteUser(enterpriseDTO.getCorpid(), application.getSiteId(), userArr);
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1);
		
	}
	
	@RequestMapping("staff-batch-edit-department")
	public HaobanResponse staffBatchEditDepartment(String params){
		List<StaffEditJsonQO> list = JSON.parseArray(params, StaffEditJsonQO.class);
		for (StaffEditJsonQO staffEditJsonQO : list) {
			String staffDepartmentRelatedId = staffEditJsonQO.getStaffDepartmentRelatedId();
			String departmentIds = staffEditJsonQO.getCurrDepartmentIds();
			StaffDepartmentRelatedDTO related = staffDepartmentRelatedApiService.getByStaffDepartmentRelatedId(staffDepartmentRelatedId);
			if(related != null) {
				StaffDTO staff = staffApiService.selectById(related.getStaffId());
				if(staff != null) {
					staffApiService.staffEdit(staff, departmentIds);
				}
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}

}
